@@ -12,5 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .priors import *
+from .google import *
 from .waseda import *
